#
# spec file for package notification-daemon
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 3.20
Name:           notification-daemon
Version:        3.20.0
Release:        7.9
Summary:        Notification Daemon
License:        GPL-2.0-or-later
Group:          System/Daemons
URL:            https://galago-project.org/
Source:         https://download.gnome.org/sources/notification-daemon/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0) >= 2.27.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.19.5
BuildRequires:  pkgconfig(x11)
Provides:       dbus(org.freedesktop.Notifications)

%description
D-BUS notification daemon.

%lang_package

%prep
%setup -q

%build
%configure \
  --disable-static
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file %{name}

%if 0%{?suse_version} <= 1315
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
# README is empty
%license COPYING
%doc AUTHORS ChangeLog NEWS
%{_libexecdir}/%{name}
%{_datadir}/applications/%{name}.desktop

%files lang -f %{name}.lang

%changelog
* Tue Apr 19 2022 Dirk Müller <dmueller@suse.com>
- skip empty post/postuninstalls on SLE15+
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb 28 2017 sor.alexei@meowr.ru
- Provide dbus(org.freedesktop.Notifications), a virtual package
  by analogy with dbus(org.freedesktop.secrets).
- Minor spec cleanup.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Wed Apr  6 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Remove GNOME-Flashback autostart file.
  + Stop using deprecated GdkDeviceManager.
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.18.2:
  + Updated translations.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fix empty body text with invalid pango markup.
  + Updated translations.
* Thu Sep 24 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Deprecation warning fixes.
  + Internationalization fixes.
  + Now upstream gettext is used instead of intltool.
  + Ported away from gnome-common.
  + Updated translations.
- Drop intltool BuildRequires: no longer needed after the port to
  gettext.
- Dro ppkgconfig(libcanberra-gtk3) BuildRequires: no longer needed.
* Sun Jun  7 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Updated translations.
* Wed Apr 29 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Fix resident notifications.
  + Reset timeout when updating notification content.
  + Style fixes, should look better with Adwaita theme.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Fix timeout, based on patch by Jakub Adam.
  + Properly check if GVariant is string.
  + Fix crash in hint_to_boolean.
* Thu Mar 26 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Free memory returned by g_find_program_in_path.
  + Updated translations.
* Thu Jan 29 2015 dimstar@opensuse.org
- Update to version 3.15.2:
  + Fix few deprecation warnings.
* Thu Jan 29 2015 dimstar@opensuse.org
- Update to version 3.14.1:
  + Rename existing .desktop file to
    notification-daemon-autostart.desktop and add back regular
    .desktop file.
- Changes from version 3.14.0:
  + Desktop file moved to autostart.
  + Fix notifications with long text.
  + Updated .doap file.
  + Fix crash with newer glib versions.
  + Fix crash in nd_notification_get_is_transient.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 0.7.6:
  + Fix a wrong loop condition
  + Updated translations.
* Wed Jun  6 2012 dimstar@opensuse.org
- Update to version 0.7.5:
  + Updated translations.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 0.7.4:
  + Updated translations.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 0.7.3:
  + Updated translations.
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 0.7.2:
  + Remove vestigial dbus-glib requirement
  + Updated translations.
- Remove now unneeded dbus-1-glib-devel BuildRequires.
* Thu Apr 21 2011 vuntz@opensuse.org
- Drop --libexecdir=%%{_libexecdir}/%%{name}-1.0 from configure: we
  don't need a specific libexecdir.
- Remove now unneeded libnotify-devel, libwnck-devel BuildRequires.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: libcanberra-devel.
  + New ones: glib-2.0, gtk+-3.0, libcanberra-gtk3, x11.
* Thu Mar 24 2011 fcrozat@novell.com
- Update to version 0.7.1:
  + Don't use DBus activation
  + Don't exit on idle
  + Install a desktop file for notification-daemon
- Changes from version 0.7.0:
  + Support image-data and image-path hints
  + Updated translations.
- Changes from version 0.6.0:
  + Drop setup capplet
  + Drop themes
  + Add a 'dock' for bubbles
  + Add 'persistence' and 'action-icons' capabilities
  + Support transient and resident notifications
  + Port to GDBus
- Remove GConf schema handling (no longer used upstream)
- Remove fdupes and gconf2-devel BuildRequires.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Sun Aug  8 2010 vuntz@opensuse.org
- Clean up update to 0.5.0.
- Remove gstreamer-0_10-devel BuildRequires, now that libcanberra
  is used.
* Thu Jul 29 2010 dimstar@opensuse.org
- Update to version 0.5.0:
  + Add a new default theme
  + Properly handle monitor changes
  + Add multi-screen support
  + Exit when not in use
  + Exit when unable to acquire bus name
  + Support version 1.1 of the notification spec
  + Various memory leak fixes
  + Better RTL locale support
  + Don't monitor all X events unless necessary
  + Update the list of ways to start a browser
  + Fix the screensaver lock detection
  + Use top right location by default
  + Use canberra instead of gstreamer for event sounds
  + Limit the total number of notifications that can be displayed
    at once
  + Conversion from glade to gtkbuilder
  + Bugs fixed: bgo#608077, bgo#608082, bgo#608858, bgo#612032,
    bgo#622021, bgo#622552, bgo#622556
- Drop notification-daemon-memleak.patch,
  notification-daemon-no-libsexy.patch and
  notification-daemon-crash-theme-change.patch: fixed upstream.
- Drop notification-daemon-new-bubble.patch and the packaging hacks
  to create our bubble theme based on the standard theme. There is
  now a nice upstream theme included that we will use instead.
- Add libcanberra-devel BuildRequires.
- Remove libglade2-devel BuildRequires.
* Mon Jun 28 2010 sbrabec@suse.cz
- Added support for translation-update-upstream (bnc#617754).
* Thu Jun  3 2010 vuntz@opensuse.org
- Add notification-daemon-no-libsexy.patch: we don't need libsexy
  to implement a feature available in recent GTK+. And it turns out
  that it fixes the crash reported as bnc#589250, so use this patch
  from upstream.
- Drop libsexy-devel BuildRequires.
* Thu Dec  3 2009 vuntz@opensuse.org
- Rebase notification-daemon-new-bubble.patch to apply without
  fuzz.
* Sat Apr 25 2009 vuntz@novell.com
- Add notification-daemon-crash-theme-change.patch to fix a crash
  when the notification theme changes while a notification is
  opened. Fix bnc#496430.
* Thu Apr 23 2009 vuntz@novell.com
- Review changes.
* Thu Apr  9 2009 opensuse@sukimashita.com
- Make notification-properties appear in control-center's look and
  feel category
* Fri Jan 23 2009 vuntz@novell.com
- Minor spec cleanups.
* Sat Dec 20 2008 mboman@suse.de
- Update to version 0.4.0:
  + Bumped up the required minimum version of GTK+ to 2.10.0.
  + Bump the notification spec version we're compliant with to 1.0.
  + Send the reason code along with the NotificationClosed signal in order
    to indicate why the notification was closed
  + Send an error if the user attempts to close an already closed
    notification.
  + Text is now escaped in the summary in the Standard theme so that
    ampersands and other special characters show up instead of disappearing.
  + Set the type hint for notifications to TYPE_NOTIFICATION
  + Added support for playing sounds when the "sound-file" hint is set or
    when the default_sound GConf key is set, as well as support for the
    "suppress-sound" hint
  + Added a control panel applet for controlling such things as the
    notification theme and popup positions
  + Added better support for attaching context notifications to an icon on
    the system tray, even when it moves
  + Added an Arabic translation
  + Added an Italian translation
  + Fixed a bug where text would sometimes get truncated
  + Fixed a bug where notifications weren't displayed if a fullscreen
    window was minimized
  + Fixed a bug where we were quitting on theme engine failure, instead of
    falling back to the default theme engine
  + Fixed a bug where notifications with arrows were crossing the monitor
    on multihead setups instead of staying on their head
  + Fixed the close button size on the notifications so that they don't
    stretch
  + Fixed a crash when an unsupported value type was passed in for the
    urgency when using the standard theme
- Remove backported notification-daemon-svn3017.patch
- Remove notification-daemon-clipping.patch. Fixed upstream
* Mon Oct 27 2008 vuntz@novell.com
- Add notification-daemon-svn3017.patch to get many fixes from
  upstream that never made into a release since early 2007.
- Add notification-daemon-memleak.patch to fix a leak.
- Add gstreamer-0_10-devel as BuildRequires.
- Clean up spec file.
* Mon Mar 31 2008 vuntz@suse.de
- Remove all the bubble related patches:
  notification-daemon-bubble-enable.patch,
  notification-daemon-bubble-init.patch,
  notification-daemon-drawing.patch
- Instead, create a new theme based on the standard theme by
  copying the standard theme.
- Add notification-daemon-new-bubble.patch: we patch the
  standard-based theme to be easily themed via the GTK+ theme, and
  we also add some internal API to know if an engine wants to
  always stack notifications. This theme is named bubble to keep
  compatibility with previous versions of the package.
- Remove useless build-requires: gcc-c++ libxml2-devel
  perl-XML-Parser update-desktop-files
* Thu Mar 13 2008 sbrabec@suse.cz
- Custom look'n'feel gconf keys moved to gconf2-branding-openSUSE.
* Thu Mar  6 2008 maw@suse.de
- Fix the build when against newer versions of intltool.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Tue Mar 13 2007 dobey@suse.de
- Update drawing patch to build
- notification-daemon-bubble-enable.patch
  * Enable building the bubble theme again
- notification-daemon-bubble-init.patch
  * Add new methods requiresd for theme to load
* Tue Mar  6 2007 sbrabec@suse.cz
- Updated to version 0.3.7:
  * Bug and crash fixes.
  * Fixed memory leaks.
  * Fixed dbus 0.61 and dbus-glib 0.72 compatibility.
  * The background of the window in the standard theme is now just
    slightly transparent when compiled against GTK+ 2.10 and when
    using a composite manager.
  * Fix several rendering glitches.
  * Added initial accessibility support.
  * Clicking anywhere in a notification should now close the
    notification.
  * Added a GConf key to allow users to specify corners.
  * Translation update.
  * A notification's timeout will now pause while the mouse is
    hovering over the notification.
* Mon Mar  5 2007 sbrabec@suse.cz
- Compile with the latest dbus-binding-tool.
* Mon Dec 11 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Thu Nov 30 2006 jhargadon@suse.de
- removed unneeded files from package (#223690)
* Thu Nov 30 2006 sbrabec@suse.cz
- Build correctly in older products.
* Sat Oct 14 2006 danw@suse.de
- Remove dead patches
* Fri Sep 15 2006 jhargadon@suse.de
- update to version 0.3.5
- removed upstreamed patches
- Add three new required theme functions:
  - theme_check_init - determines if the theme is compatible with the
    running version of notification-daemon.
  - get_theme_info - returns info on the theme.
  - clear_notification_actions - Clears the notification action buttons
    on the window
- Disabled the Bubble theme for this release. It's the source of too
  many bugs
- Fix the scaling of different icon sizes. Now small icons display as
  small, and larger icons are scaled down to 48x48
- Fixed a problem where icons were being clipped in notifications
- Fixed incorrect usage of GtkIconTheme.
- Fixed notifications with a timeout of 2147484ms or longer expiring
  in less than a second
- Fixed a bug where a notification would duplicate its actions when
  updated.
- The Standard theme's countdown timer is now rendered using Cairo when
  compiled against Gtk 2.8.0 or higher. This improves the timer by making
- Renamed notification-daemon.service to
  org.freedesktop.Notifications.service
* Wed Aug 16 2006 aj@suse.de
- Add a build require on dbus-1-glib-devel.
* Tue Mar 14 2006 dobey@suse.de
- Add patch to fix default action clicking in notifications
* Mon Mar  6 2006 dobey@suse.de
- Update drawing patch to fix colors
* Mon Feb 13 2006 dobey@suse.de
- Update to version 0.3.4
- Remove upstreamed patch for unversioned plug-ins
- Add patch to fix usage of icon theme icons
- Many upstream bug fixes
- Add libwnck-devel to BuildRequires
* Thu Jan 26 2006 dobey@suse.de
- Add patch to default to new drawing theme
- Add patch to remove libtool version on plug-ins
- Add intltool to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 dobey@suse.de
- Update to version 0.3.2
- Add in patch for new drawing layout
* Sun Aug  7 2005 aj@suse.de
- Fix 64-bit bug.
* Tue Aug  2 2005 rodrigo@suse.de
- Updated to 0.2.1.
* Wed Jun 29 2005 sbrabec@suse.cz
- New SuSE package, pre-0.0.1 version from actual svn snapshot.
